tinymce.addI18n('vi',{
"Cut": "C\u1eaft",
"Header 2": "Ti\u00eau \u0111\u1ec1 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Tr\u00ecnh duy\u1ec7t c\u1ee7a b\u1ea1n kh\u00f4ng h\u1ed7 tr\u1ee3 truy c\u1eadp truy c\u1eadp b\u1ed9 nh\u1edb \u1ea3o, vui l\u00f2ng s\u1eed d\u1ee5ng c\u00e1c t\u1ed5 h\u1ee3p ph\u00edm Ctrl + X, C, V.",
"Div": "Khung",
"Paste": "D\u00e1n",
"Close": "\u0110\u00f3ng L\u1ea1i",
"Pre": "\u0110\u1ecbnh d\u1ea1ng",
"Align right": "Canh ph\u1ea3i",
"New document": "T\u1ea1o t\u00e0i li\u1ec7u m\u1edbi",
"Blockquote": "\u0110o\u1ea1n Tr\u00edch D\u1eabn",
"Numbered list": "Danh s\u00e1ch d\u1ea1ng s\u1ed1",
"Increase indent": "T\u0103ng kho\u1ea3ng c\u00e1ch d\u00f2ng",
"Formats": "\u0110\u1ecbnh d\u1ea1ng",
"Headers": "\u0110\u1ea7u trang",
"Select all": "Ch\u1ecdn t\u1ea5t c\u1ea3",
"Header 3": "Ti\u00eau \u0111\u1ec1 3",
"Blocks": "Bao",
"Undo": "H\u1ee7y thao t\u00e1c",
"Strikethrough": "G\u1ea1ch ngang",
"Bullet list": "Danh s\u00e1ch d\u1ea1ng bi\u1ec3u t\u01b0\u1ee3ng",
"Header 1": "Ti\u00eau \u0111\u1ec1 1",
"Superscript": "K\u00fd t\u1ef1 m\u0169",
"Clear formatting": "L\u01b0\u1ee3c b\u1ecf ph\u1ea7n hi\u1ec7u \u1ee9ng",
"Subscript": "K\u00fd t\u1ef1 th\u1ea5p",
"Header 6": "Ti\u00eau \u0111\u1ec1 6",
"Redo": "L\u00e0m l\u1ea1i",
"Paragraph": "\u0110o\u1ea1n v\u0103n",
"Ok": "\u0110\u1ed3ng \u00dd",
"Bold": "In \u0111\u1eadm",
"Code": "M\u00e3",
"Italic": "In nghi\u00eang",
"Align center": "Canh gi\u1eefa",
"Header 5": "Ti\u00eau \u0111\u1ec1 5",
"Decrease indent": "Th\u1ee5t l\u00f9i d\u00f2ng",
"Header 4": "Ti\u00eau \u0111\u1ec1 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "D\u00e1n \u0111ang trong tr\u1ea1ng th\u00e1i v\u0103n b\u1ea3n thu\u1ea7n. N\u1ed9i dung s\u1ebd \u0111\u01b0\u1ee3c d\u00e1n d\u01b0\u1edbi d\u1ea1ng v\u0103n b\u1ea3n thu\u1ea7n, kh\u00f4ng \u0111\u1ecbnh d\u1ea1ng.",
"Underline": "G\u1ea1ch d\u01b0\u1edbi",
"Cancel": "Hu\u1ef7 B\u1ecf",
"Justify": "Canh \u0111\u1ec1u hai b\u00ean",
"Inline": "C\u00f9ng d\u00f2ng",
"Copy": "Sao ch\u00e9p",
"Align left": "Canh tr\u00e1i",
"Visual aids": "M\u1edf khung so\u1ea1n th\u1ea3o",
"Lower Greek": "S\u1ed1 hy l\u1ea1p th\u01b0\u1eddng",
"Square": "\u00d4 vu\u00f4ng",
"Default": "Ng\u1ea7m \u0111\u1ecbnh",
"Lower Alpha": "K\u00fd t\u1ef1 th\u01b0\u1eddng",
"Circle": "H\u00ecnh tr\u00f2n",
"Disc": "H\u00ecnh tr\u00f2n m\u1ecfng",
"Upper Alpha": "K\u00fd t\u1ef1 hoa",
"Upper Roman": "S\u1ed1 la m\u00e3 hoa",
"Lower Roman": "S\u1ed1 la m\u00e3 th\u01b0\u1eddng",
"Insert row before": "Th\u00eam d\u00f2ng ph\u00eda tr\u00ean",
"Rows": "D\u00f2ng",
"Height": "Cao",
"Paste row after": "D\u00e1n v\u00e0o ph\u00eda sau, d\u01b0\u1edbi",
"Alignment": "Canh ch\u1ec9nh",
"Column group": "Nh\u00f3m c\u1ed9t",
"Row": "D\u00f2ng",
"Insert column before": "Th\u00eam c\u1ed9t b\u00ean tr\u00e1i",
"Split cell": "Chia \u00f4",
"Cell padding": "Kho\u1ea3ng c\u00e1ch trong \u00f4",
"Cell spacing": "Kho\u1ea3ng c\u00e1ch \u00f4",
"Row type": "Lo\u1ea1i d\u00f2ng",
"Insert table": "Th\u00eam b\u1ea3ng",
"Body": "N\u1ed9i dung",
"Caption": "Ti\u00eau \u0111\u1ec1",
"Footer": "Ch\u00e2n",
"Delete row": "Xo\u00e1 d\u00f2ng",
"Paste row before": "D\u00e1n v\u00e0o ph\u00eda tr\u01b0\u1edbc, tr\u00ean",
"Scope": "Quy\u1ec1n",
"Delete table": "Xo\u00e1 b\u1ea3ng",
"Header cell": "Ti\u00eau \u0111\u1ec1 \u00f4",
"Column": "C\u1ed9t",
"None": "Kh\u00f4ng",
"Cell": "\u00d4",
"Header": "Ti\u00eau \u0111\u1ec1",
"Border": "\u0110\u01b0\u1eddng vi\u1ec1n",
"Cell type": "Lo\u1ea1i \u00f4",
"Copy row": "Ch\u00e9p d\u00f2ng",
"Row properties": "Thu\u1ed9c t\u00ednh d\u00f2ng",
"Table properties": "Thu\u1ed9c t\u00ednh b\u1ea3ng",
"Row group": "Nh\u00f3m d\u00f2ng",
"Right": "Ph\u1ea3i",
"Insert column after": "Th\u00eam c\u1ed9t b\u00ean ph\u1ea3i",
"Cols": "C\u1ed9t",
"Insert row after": "Th\u00eam d\u00f2ng ph\u00eda d\u01b0\u1edbi",
"Width": "R\u1ed9ng",
"Cell properties": "Thu\u1ed9c t\u00ednh \u00f4",
"Left": "Tr\u00e1i",
"Cut row": "C\u1eaft d\u00f2ng",
"Delete column": "Xo\u00e1 c\u1ed9t",
"Center": "Gi\u1eefa",
"Merge cells": "N\u1ed1i \u00f4"
});