tinymce.addI18n('de',{
"Cut": "Schneiden",
"Header 2": "\u00dcberschrift 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Ihr Browser unterst\u00fctzt leider keine direkten Zugriff auf die Zwischenablage. Bitte benutzen Sie die Strg + X \/ C \/ V Tastenkombinationen.",
"Div": "Textblock",
"Paste": "Einf\u00fcgen",
"Close": "Schliessen",
"Pre": "Vorformatierter Text",
"Align right": "Rechts ausrichten ",
"New document": "Neues Dokument",
"Blockquote": "Zitat",
"Numbered list": "Alphabetische Sortierung",
"Increase indent": "Einr\u00fcckung vergr\u00f6\u00dfern",
"Formats": "Formate",
"Headers": "\u00dcberschriften",
"Select all": "Alles ausw\u00e4hlen",
"Header 3": "\u00dcberschrift 3",
"Blocks": "Bl\u00f6cke",
"Undo": "Undo",
"Strikethrough": "Durchstreichen",
"Bullet list": "Aufz\u00e4hlungszeichen",
"Header 1": "\u00dcberschrift 1",
"Superscript": "Exponent",
"Clear formatting": "Klare Formatierung ",
"Subscript": "tiefstehendes Zeichen",
"Header 6": "\u00dcberschrift 6",
"Redo": "Redo",
"Paragraph": "Absatz",
"Ok": "Ok",
"Bold": "Bold",
"Code": "Quelltext",
"Italic": "Italic",
"Align center": "Zentriert ausrichten",
"Header 5": "\u00dcberschrift 5",
"Decrease indent": "Einzug verringern",
"Header 4": "\u00dcberschrift 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Einf\u00fcgungen erfolgen bis auf Weiteres als reiner Text. ",
"Underline": "Unterstreichen",
"Cancel": "Abbrechen",
"Justify": "Blockausrichtung",
"Inline": "zeilenb\u00fcndig",
"Copy": "Kopieren",
"Align left": "Ausrichtung nach links",
"Visual aids": "Visuelle Hilfen",
"Lower Greek": "Lower Greek",
"Square": "Quadrat",
"Default": "Voreingestellt",
"Lower Alpha": "Lower Alpha",
"Circle": "Zirkel",
"Disc": "Disc",
"Upper Alpha": "Upper Alpha",
"Upper Roman": "Upper Roman",
"Lower Roman": "Lower Roman",
"Name": "Name",
"Anchor": "Textmarke",
"You have unsaved changes are you sure you want to navigate away?": "Sie haben noch nicht die \u00c4nderungen gespeichert, sind Sie sicher dass Sie weg navigieren wollen ? ",
"Restore last draft": "Zur\u00fcckholen den letzten Entwurf",
"Special character": "Spezieller Charakter",
"Source code": "Quellcode",
"Right to left": "Links nach Rechts",
"Left to right": "Rechts nach Links",
"Emoticons": "Emoticons",
"Robots": "Robots",
"Document properties": "Dokumenteigenschaften",
"Title": "Titel",
"Keywords": "Sch\u00fcsselw\u00f6rter",
"Encoding": "Enkodieren",
"Description": "Beschreibung",
"Author": "Ersteller",
"Fullscreen": "Vollbild",
"Horizontal line": "Horizontale Linie",
"Horizontal space": "Horizontaler Platz",
"Insert\/edit image": "Bild bearbeiten",
"General": "Allgemein",
"Advanced": "Benutzerdefiniert",
"Source": "Quelle",
"Border": "Grenze",
"Constrain proportions": "Gr\u00f6ssenverh\u00e4ltniss",
"Vertical space": "Vertikaler Platz",
"Image description": "Bild Beschreibung",
"Style": "Stil",
"Dimensions": "Dimensionen",
"Insert image": "Bild einf\u00fcgen",
"Insert date\/time": "Datum \/ Uhrzeit einf\u00fcgen ",
"Remove link": "Verweis entfernen",
"Url": "Url",
"Text to display": "Text anzeigen",
"Anchors": "Textmarken",
"Insert link": "Link einf\u00fcgen",
"New window": "Neues Fenster",
"None": "Nichts",
"Target": "Ziel",
"Insert\/edit link": "Link Einf\u00fcgen\/bearbeiten",
"Insert\/edit video": "Video Einf\u00fcgen\/bearbeiten",
"Poster": "Poster",
"Alternative source": "Alternative Quelle",
"Paste your embed code below:": "F\u00fcgen Sie Ihren code hier:",
"Insert video": "Video einf\u00fcgen",
"Embed": "Einbetten",
"Nonbreaking space": "Gesch\u00fctztes Leerzeichen",
"Page break": "Seitenumbruch",
"Preview": "Voransicht",
"Print": "Drucken",
"Save": "Speichern",
"Could not find the specified string.": "Konnte nicht gefunden die angegebene Zeichenfolge.",
"Replace": "Ersetzen",
"Next": "N\u00e4chstes",
"Whole words": "Ganze W\u00f6rter",
"Find and replace": "Finden und ersetzen",
"Replace with": "Ersetzen mit",
"Find": "Finden",
"Replace all": "Alles ersetzen",
"Match case": "Gro\u00df-\/Kleinschreibung",
"Prev": "Vor",
"Spellcheck": "Rechtschreibpr\u00fcfung",
"Finish": "Ende",
"Ignore all": "Alles Ignorieren",
"Ignore": "Ignorieren",
"Insert row before": "Zeile einf\u00fcgen bevor ",
"Rows": "Zeilen",
"Height": "H\u00f6he",
"Paste row after": "Zelle danach einf\u00fcgen",
"Alignment": "Ausrichtung ",
"Column group": "Spalten gruppen",
"Row": "Zeile",
"Insert column before": "Spalte einf\u00fcgen bevor ",
"Split cell": "Zellen splitten",
"Cell padding": "Zellauff\u00fcllung ",
"Cell spacing": "Zellenabstand",
"Row type": "Zellentypen",
"Insert table": "Tabelle einf\u00fcgen",
"Body": "K\u00f6rper",
"Caption": "Titel",
"Footer": "Fu\u00dfzeile",
"Delete row": "Zelle l\u00f6schen",
"Paste row before": "Zelle bevor einf\u00fcgen",
"Scope": "Rahmen",
"Delete table": "Tabelle l\u00f6schen",
"Header cell": "Kopfzelle ",
"Column": "Spalte",
"Cell": "Zelle",
"Header": "Kopfzeile",
"Cell type": "Zellentyp",
"Copy row": "Zelle Kopieren",
"Row properties": "Zelle Proportionen",
"Table properties": "Tabelleproportionen",
"Row group": "Zellen gruppen",
"Right": "Rechts",
"Insert column after": "Spalte danach einf\u00fcgen",
"Cols": "Cols",
"Insert row after": "Zelle danach einf\u00fcgen",
"Width": "Breite",
"Cell properties": "Zellenproportionen",
"Left": "Links",
"Cut row": "Zelle schneiden",
"Delete column": "Spalte l\u00f6schen",
"Center": "Zentrum",
"Merge cells": "Zellen verbinden",
"Insert template": "Vorlage einf\u00fcgen ",
"Templates": "Vorlagen",
"Background color": "Hintergrundfarbe",
"Text color": "Textfarbe",
"Show blocks": " Bl\u00f6cke anzeigen",
"Show invisible characters": "Zeigen unsichtbare Zeichen",
"Words: {0}": "W\u00f6rter: {0}",
"Insert": "Einf\u00fcgen",
"File": "Datei",
"Edit": "Bearbeiten",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich-Text- Area. Dr\u00fccken Sie ALT -F9 f\u00fcr das Men\u00fc. Dr\u00fccken Sie ALT -F10 f\u00fcr Symbolleiste. Dr\u00fccken Sie ALT -0 f\u00fcr Hilfe",
"Tools": "Tools",
"View": "Anzeigen",
"Table": "Tabelle",
"Format": "Format"
});