tinymce.addI18n('de_AT',{
"Cut": "Ausschneiden",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Ihr Browser unterst\u00fctzt keinen direkten Zugriff auf die Zwischenablage. Bitte nutzen Sie die Tastaturk\u00fcrzel Strg+X\/C\/V stattdessen.",
"Paste": "Einf\u00fcgen",
"Close": "Schlie\u00dfen",
"Align right": "Rechtsb\u00fcndig",
"New document": "Neues Dokument",
"Numbered list": "Sortierte Liste",
"Increase indent": "Einr\u00fccken",
"Formats": "Formate",
"Select all": "Alles ausw\u00e4hlen",
"Undo": "Wiederholen",
"Strikethrough": "Durchgestrichen",
"Bullet list": "Unsortierte Liste",
"Superscript": "Hochgestellt",
"Clear formatting": "Formatierungen zur\u00fccksetzen",
"Subscript": "Tiefgestellt",
"Redo": "R\u00fcckg\u00e4ngig",
"Ok": "Ok",
"Bold": "Fett",
"Italic": "Kursiv",
"Align center": "Zentriert",
"Decrease indent": "Ausr\u00fccken",
"Underline": "Unterstrichen",
"Cancel": "Abbrechen",
"Justify": "Blocksatz",
"Copy": "Kopieren",
"Align left": "Linksb\u00fcndig",
"Visual aids": "Hilfslinien und unsichtbare Elemente einblenden",
"Lower Greek": "Griechische Kleinbuchstaben",
"Square": "Quadrat",
"Default": "Standard",
"Lower Alpha": "Kleinbuchstaben",
"Circle": "Kreis",
"Disc": "Scheibe",
"Upper Alpha": "Griechische Gro\u00dfbuchstaben",
"Upper Roman": "R\u00f6mische Gro\u00dfbuchstaben",
"Lower Roman": "R\u00f6mische Kleinbuchstaben",
"Name": "Name",
"Anchor": "Anker",
"You have unsaved changes are you sure you want to navigate away?": "Sie haben ungespeicherte \u00c4nderungen. Sind Sie sicher, dass Sie die Seite verlassen wollen?",
"Restore last draft": "Letzten Entwurf speichern.",
"Special character": "Sonderzeichen",
"Source code": "Quelltext",
"Right to left": "Rechts nach links",
"Left to right": "Links nach rechts",
"Emoticons": "Emoticons",
"Robots": "Suchmaschinen",
"Document properties": "Dokumenteigenschaften",
"Title": "Titel",
"Keywords": "Schl\u00fcsselw\u00f6rter",
"Encoding": "Encoding",
"Description": "Beschreibung",
"Author": "Author",
"Fullscreen": "Vollbild",
"Horizontal line": "Horizontale Trennlinie",
"Horizontal space": "Horizontaler Abstand",
"Insert\/edit image": "Bild einf\u00fcgen\/bearbeiten",
"General": "Allgemein",
"Advanced": "Erweitert",
"Source": "Adresse",
"Border": "Rahmen",
"Constrain proportions": "Seitenverh\u00e4ltnis beibehalten",
"Vertical space": "Vertikaler Abstand",
"Image description": "Bildbeschreibung",
"Style": "Format",
"Dimensions": "Ausma\u00dfe",
"Insert date\/time": "Zeit\/Datum einf\u00fcgen",
"Url": "Url",
"Text to display": "Angezeigter Text",
"Insert link": "Link einf\u00fcgen",
"New window": "Neues Fenster",
"None": "Keine",
"Target": "Ziel",
"Insert\/edit link": "Link einf\u00fcgen\/bearbeiten",
"Insert\/edit video": "Video einf\u00fcgen\/bearbeiten",
"Poster": "Poster",
"Alternative source": "Alternative Quelle",
"Paste your embed code below:": "F\u00fcgen unten Sie Ihren Quellcode zum einbetten ein",
"Insert video": "Video einf\u00fcgen",
"Embed": "Einbetten",
"Nonbreaking space": "gesch\u00fctztes Leerzeichen",
"Page break": "Seitenumbruch",
"Preview": "Vorschau",
"Print": "Drucken",
"Save": "Speichern",
"Could not find the specified string.": "Keine \u00dcbereinstimmung gefunden",
"Replace": "Ersetzen",
"Next": "N\u00e4chstes",
"Whole words": "Vollst\u00e4ndige W\u00f6rter",
"Find and replace": "Suchen und ersetzen",
"Replace with": "Ersetzen mit",
"Find": "Suchen",
"Replace all": "Alle ersetzen",
"Match case": "Gro\u00df-\/Kleinschreibung beachten",
"Prev": "Vorheriges",
"Spellcheck": "Rechtschreibung \u00fcberpr\u00fcfen",
"Finish": "Fertig",
"Ignore all": "Alle ignorieren",
"Ignore": "Ignorieren",
"Insert row before": "Neue Zeile oberhalb einf\u00fcgen",
"Rows": "Zeilen",
"Height": "H\u00f6he",
"Paste row after": "Zeile unterhalb einf\u00fcgen",
"Alignment": "Ausrichtung",
"Column group": "Spaltengruppe",
"Row": "Zeile",
"Insert column before": "Neue Spalte links einf\u00fcgen",
"Split cell": "Verbundene Zellen trennen",
"Cell padding": "Abstand innerhalb der Zellen",
"Cell spacing": "Zellenabstand",
"Row type": "Zeilentyp",
"Insert table": "Tabelle einf\u00fcgen",
"Body": "Tabellenk\u00f6rper",
"Caption": "Beschriftung der Tabelle",
"Footer": "Tabellenfu\u00df",
"Delete row": "Zeile l\u00f6schen",
"Paste row before": "Zeile oberhalb einf\u00fcgen",
"Scope": "Geltungsbereich",
"Delete table": "Tabelle l\u00f6schen",
"Header cell": "\u00dcberschrift",
"Column": "Spalte",
"Cell": "Zelle",
"Header": "\u00dcberschrift",
"Cell type": "Zellentyp",
"Copy row": "Zeile kopieren",
"Row properties": "Zeileneigenschaften",
"Table properties": "Tabelleneigenschaften",
"Row group": "Zeilengruppe",
"Right": "Rechts",
"Insert column after": "Neue Spalte rechts einf\u00fcgen",
"Cols": "Spalten",
"Insert row after": "Neue Zeile unterhalb einf\u00fcgen",
"Width": "Breite",
"Cell properties": "Zelleneigenschaften",
"Left": "Links",
"Cut row": "Zeile ausschneiden",
"Delete column": "Spalte l\u00f6schen",
"Center": "Zentriert",
"Merge cells": "Zellen vereinen",
"Insert template": "Vorlage einf\u00fcgen",
"Templates": "Vorlagen",
"Background color": "Hintergrundfarbe",
"Text color": "Textfarbe",
"Show blocks": "Blockelemente einblenden",
"Show invisible characters": "Unsichtbare Zeichen einblenden",
"Words: {0}": "W\u00f6rter: {0}",
"Insert": "Einf\u00fcgen",
"File": "Datei",
"Edit": "Bearbeiten",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text Area. Dr\u00fccken Sie ALT-F9 f\u00fcr das Men\u00fc. Dr\u00fccken Sie ALT-F10 f\u00fcr die Werkzeugleiste. Dr\u00fccken Sie ALT-0 f\u00fcr Hilfe",
"Tools": "Extras",
"View": "Ansicht",
"Table": "Tabelle",
"Format": "Format"
});